@@ -7,10 +7,11 @@ pub mod upsert;
 use std::sync::Arc;
 
 pub use crate::client::iotics::api::feed_api_client::FeedApiClient;
+pub use crate::client::iotics::api::list_all_twins_response::TwinDetails;
 pub use crate::client::iotics::api::twin_api_client::TwinApiClient;
 pub use crate::client::iotics::api::{
     DescribeFeedResponse, DescribeTwinResponse, FetchInterestRequest, FetchInterestResponse,
-    ListAllTwinsResponse, Twin, UpsertFeedWithMeta, UpsertTwinResponse,
+    ListAllTwinsResponse, UpsertFeedWithMeta, UpsertTwinResponse,
 };
 
 use crate::auth_builder::IntoAuthBuilder;
